Density, distribution function, hazard function, quantile function, and random generation for the loss to follow-up distribution.
dloss(x, arm)ploss(q, arm, lower.tail = T)
hloss(x, arm)
qloss(p, arm, lower.tail = T)
rloss(n = 1, arm)
dloss gives the density, ploss gives the distribution
function, hloss gives the hazard function, qloss gives the
quantile function, and rloss generates random deviates.
vector of quantiles.
object of class 'arm'.
logical; if TRUE, probabilities are \(P(X \le x)\); otherwise, \(P(X > x)\).
vector of probabilities.
number of observations.
create_arm and create_arm_lachin
for creating an object of class 'arm'.