Density, distribution function, hazard function, quantile function, and random generation for the survival distribution.
dsurv(x, arm, include_cured = T)psurv(q, arm, include_cured = T, lower.tail = T)
hsurv(x, arm, include_cured = T)
qsurv(p, arm, include_cured = T, lower.tail = T)
rsurv(n = 1, arm, include_cured = T)
dsurv gives the density, psurv gives the distribution
function, hsurv gives the hazard function, qsurv gives the
quantile function, and rsurv generates random deviates.
vector of quantiles.
object of class arm.
logical; if TRUE, mixture distribution of cured and uncured patients is considered; otherwise, only the distribution for uncured patients is considered.
logical; if TRUE, probabilities are \(P(X \le x)\); otherwise, \(P(X > x)\).
vector of probabilities.
number of observations.
create_arm and create_arm_lachin
for creating an object of class 'arm'.